@@ -144,6 +144,9 @@ class YOLOExtendedParser(BaseParser):
         if not isinstance(threshold, float):
             raise ValueError("Confidence score threshold must be a float.")
 
+        if threshold < 0 or threshold > 1:
+            raise ValueError("Confidence score threshold must be between 0 and 1.")
+
         self.conf_threshold = threshold
         self._logger.debug(f"Confidence score threshold set to {self.conf_threshold}")
 
@@ -523,8 +526,11 @@ class YOLOExtendedParser(BaseParser):
                 )
 
             detections_message.setTimestamp(output.getTimestamp())
-            detections_message.setTransformation(output.getTransformation())
+            detections_message.setTimestampDevice(output.getTimestampDevice())
             detections_message.setSequenceNum(output.getSequenceNum())
+            transformation = output.getTransformation()
+            if transformation is not None:
+                detections_message.setTransformation(transformation)
 
             self._logger.debug(
                 f"Created detection message with {len(bboxes)} detections"
